@@ -2,13 +2,12 @@
 Common date types and APIs
 """
 from datetime import datetime
-from enum import Enum
 from typing import Optional, Any
 
 from pydantic import Field, root_validator, validator
 
-from wxc_sdk.base import ApiModel
-from ..base import webex_id_to_uuid
+from ..base import ApiModel, webex_id_to_uuid
+from ..base import SafeEnum as Enum
 
 __all__ = ['UserType', 'UserBase', 'RingPattern', 'AlternateNumber', 'Greeting', 'UserNumber', 'PersonPlaceAgent',
            'MonitoredMember', 'CallParkExtension', 'AuthCode', 'RouteType', 'DialPatternValidate', 'DialPatternStatus',
@@ -138,7 +137,7 @@ class CallParkExtension(ApiModel):
     extension: Optional[str]
     #: The location name where the call park extension is.
     location_name: Optional[str]
-    #: The location Id for the location.
+    #: The location ID for the location.
     location_id: Optional[str]
 
     @root_validator(pre=True)
@@ -210,7 +209,7 @@ class Customer(ApiModel):
     """
     Customer information.
     """
-    #: Id of the customer/organization.
+    #: ID of the customer/organization.
     customer_id: str = Field(alias='id')
     #: Name of the customer/organization.
     name: str
@@ -439,6 +438,7 @@ class AtaCustomization(CommonDeviceCustomization):
     ata_dtmf_mode: AtaDtmfMode
     #: Method for transmitting DTMF signals to the far end.
     ata_dtmf_method: AtaDtmfMethod
+    snmp: dict
 
 
 class BacklightTimer(str, Enum):
@@ -577,7 +577,7 @@ class WifiNetwork(ApiModel):
     authentication_method: str
     #: SSID name of the wifi network.
     ssid_name: Optional[str]
-    #: User Id of the wifi network.
+    #: User ID of the wifi network.
     user_id: Optional[str]
 
 
