@@ -3,13 +3,13 @@ Schedules for locations or users
 """
 import datetime
 from collections.abc import Generator
-from enum import Enum
 from typing import Optional, Union
 
 from pydantic import Field
 
 from ..api_child import ApiChild
 from ..base import ApiModel
+from ..base import SafeEnum as Enum
 from ..rest import RestSession
 
 __all__ = ['ScheduleApi', 'ScheduleType', 'ScheduleMonth', 'ScheduleDay', 'ScheduleWeek', 'RecurWeekly',
@@ -226,6 +226,7 @@ class Event(ApiModel):
             start_time = datetime.time(start_time)
         if isinstance(end_time, int):
             end_time = datetime.time(end_time)
+        # noinspection PyArgumentList
         return Event(name=name,
                      start_date=day, end_date=day,
                      start_time=start_time,
@@ -289,11 +290,11 @@ class Schedule(ApiModel):
             # Two events
             # * from start to break
             # * from break end to end of day
-            schedule.events.append(Event.day_start_end(name=f'{day.value} 1',
+            schedule.events.append(Event.day_start_end(name=f'{day} 1',
                                                        day=dt_day,
                                                        start_time=day_start,
                                                        end_time=break_start))
-            schedule.events.append(Event.day_start_end(name=f'{day.value} 2',
+            schedule.events.append(Event.day_start_end(name=f'{day} 2',
                                                        day=dt_day,
                                                        start_time=break_end,
                                                        end_time=day_end))
