@@ -51,8 +51,10 @@ class OwnerType(str, Enum):
     place = 'PLACE'
     auto_attendant = 'AUTO_ATTENDANT'
     call_center = 'CALL_CENTER'
+    call_queue = 'CALL_QUEUE'
     group_paging = 'GROUP_PAGING'
     hunt_group = 'HUNT_GROUP'
+    virtual_line = 'VIRTUAL_LINE'
     voice_messaging = 'VOICE_MESSAGING'
     broadworks_anywhere = 'BROADWORKS_ANYWHERE'
     contact_center_link = 'CONTACT_CENTER_LINK'
@@ -405,9 +407,9 @@ class SupportedDevice(ApiModel):
     #: The default upgrade channel.
     default_upgrade_channel: Optional[str]
     #: Enables / disables the additional primary line appearances.
-    additional_primary_line_appearances_enabled: bool
+    additional_primary_line_appearances_enabled: Optional[bool]
     #: Enables / disables Basic emergency nomadic.
-    basic_emergency_nomadic_enabled: bool
+    basic_emergency_nomadic_enabled: Optional[bool]
     #: Enables / disables customized behavior support on devices
     customized_behaviors_enabled: bool
     #: Enables / disables configuring port support on device.
