@@ -1,12 +1,12 @@
 import json
 from collections.abc import Generator
-from enum import Enum
 from typing import Optional, Literal
 
 from pydantic import Field
 
 from ..api_child import ApiChild
 from ..base import ApiModel, to_camel
+from ..base import SafeEnum as Enum
 from ..common import RingPattern, PersonPlaceAgent
 
 __all__ = ['CallParkRecall', 'RecallHuntGroup', 'AvailableRecallHuntGroup',
@@ -70,6 +70,7 @@ class CallPark(ApiModel):
     recall: Optional[RecallHuntGroup]
     #: People, including workspaces, that are eligible to receive calls.
     agents: Optional[list[PersonPlaceAgent]]
+    park_on_agents_enabled: Optional[bool]
 
     @staticmethod
     def default(*, name: str) -> 'CallPark':
